# IVRE's screenshots gallery #

## Nmap results ##

![screenshot](screenshots/webui-home-heatmap.png)

Home page with "heatmap" IP addresses.


![screenshot](screenshots/webui-details-heatmapzoom.png)

Scan result details, using the "heatmap" IP addresses to "zoom" in the
address space


![screenshot](screenshots/webui-screenshots-solar-world.png)

Screenshots containing the word "solar" and map


![screenshot](screenshots/webui-topproducts-80.png)

Most common products seen on port 80


![screenshot](screenshots/webui-tooltip-topenipvendors.png)

Help tooltip and most common ENIP vendors


## Flow analysis ##

![screenshot](screenshots/webui-flow-dns-halo.png)

DNS flows with halo to show connected nodes


![screenshot](screenshots/webui-flow-details-host.png)

Flows with details for a specific host


![screenshot](screenshots/webui-flow-details-flow.png)

Flows with details for a specific flow


![screenshot](screenshots/webui-flow-flow-map.png)

Flow map


---

This file is part of IVRE. Copyright 2011 - 2015
[Pierre LALET](mailto:pierre.lalet@cea.fr)
